==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Information/InfoDistanceEP/ts/InfoDistanceEP_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>InfoDistanceEP</name>
    <message>
        <location filename="../InfoDistanceEP.js" line="+59"/>
        <source>Specify entity</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wprowadź obiekt
Wskaż obiekt do cięcia</translatorcomment>
        <translation type="unfinished">Wprowadź obiekt</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Specify point</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż punkt</translatorcomment>
        <translation type="unfinished">Wskaż punkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation type="unfinished">Zrobione</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Distance:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Odległość: %1
Zaznacz obiekt do przycięcia lub wprowadź odległość:</translatorcomment>
        <translation type="unfinished">Odległość:</translation>
    </message>
    <message>
        <location filename="../InfoDistanceEPInit.js" line="+2"/>
        <source>Distance &amp;Entity to Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Podmiot odległość do punktu</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Information/InfoDistanceEP/ts/InfoDistanceEP_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>InfoDistanceEP</name>
    <message>
        <location filename="../InfoDistanceEP.js" line="+59"/>
        <source>Specify entity</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wprowadź obiekt
Wskaż obiekt do cięcia</translatorcomment>
        <translation>Proszę wskazać obiekt</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Specify point</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż punkt</translatorcomment>
        <translation>Proszę wskazać punkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation>Zrobione</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Distance:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Odległość: %1
Zaznacz obiekt do przycięcia lub wprowadź odległość:</translatorcomment>
        <translation>Odległość:</translation>
    </message>
    <message>
        <location filename="../InfoDistanceEPInit.js" line="+2"/>
        <source>Distance &amp;Entity to Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Odległość &amp;obiektu do punktu</translation>
    </message>
</context>
</TS>
